@@ -107,9 +107,11 @@ class Check:
     expected_format: Literal['text', 'json'] | None = None
     expected: str | None = None
 
-    async def evaluate(self, depth: int = 0) -> asyncio.subprocess.Process | None:
+    async def evaluate(self, depth: int = 0) -> RunResult:
         print(' ' * depth + f"Run {self.language} code: {preview(self.code)}")
-        result: RunResult = await execute_code_block(self.code, language=self.language)
+        return await execute_code_block(self.code, language=self.language)
+
+    def check_result(self, result: RunResult, depth: int = 0) -> None:
         if result.process is not None:
             print(' ' * depth + f"Timeout {self.language} code, detach from it and kill later")
         expected = self.expected
@@ -133,7 +135,6 @@ class Check:
         else:
             print('IGNORE')
 
-        return result.process
 
 
 @dataclass
@@ -155,7 +156,11 @@ class LogicBlock:
             for block in self.content:
                 result = await block.evaluate(depth + 1)
                 if result is not None:
-                    running_processes.append(result)
+                    if result.process is not None:
+                        running_processes.append(result.process)
+                    assert isinstance(block, Check)
+                    block.check_result(result, depth + 1)
+
         finally:
             await terminate_running_processes(running_processes, depth)
 
